#ifndef NT2_INCLUDE_FUNCTIONS_ROT90_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ROT90_HPP_INCLUDED

#include <nt2/linalg/include/functions/rot90.hpp>

#endif
